==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/EntryPoints.h <==
// public class soot.jimple.toolkits.callgraph.EntryPoints

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b4a094cfa5bff62c soot_jimple_toolkits_callgraph_EntryPoints

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_EntryPoints_H_
#define _JC_soot_jimple_toolkits_callgraph_EntryPoints_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object;
struct _jc_soot_util_NumberedString$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$refs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object	_jc_soot_jimple_toolkits_callgraph_EntryPoints$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_EntryPoints$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_EntryPoints$method$addMethod$f4b9793b175f6463(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_jimple_toolkits_callgraph_EntryPoints$method$addMethod$63a13de99e7c1bf6(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_soot_SootClass$object *, struct _jc_soot_util_NumberedString$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$all$f80bf49325863443(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$application$517d3feed7d4869a(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$clinits$33c8e6b05fa0fe4c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$implicit$4fb201f0d508bb2b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$inits$937d2344fd799195(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$methodsOfApplicationClasses$ab8a3ae6562d908b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$addMethod$f4b9793b175f6463;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$addMethod$63a13de99e7c1bf6;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$all$f80bf49325863443;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$application$517d3feed7d4869a;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$clinits$33c8e6b05fa0fe4c;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$implicit$4fb201f0d508bb2b;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$inits$937d2344fd799195;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$methodsOfApplicationClasses$ab8a3ae6562d908b;

// Static methods
extern struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$v$094cc9979f5b5474(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods {
	void	(*addMethod$f4b9793b175f6463)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
	void	(*addMethod$63a13de99e7c1bf6)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_soot_SootClass$object *, struct _jc_soot_util_NumberedString$object *);
	struct _jc_object	*(*all$f80bf49325863443)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
	struct _jc_object	*(*application$517d3feed7d4869a)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
	struct _jc_object	*(*clinits$33c8e6b05fa0fe4c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
	struct _jc_object	*(*implicit$4fb201f0d508bb2b)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
	struct _jc_object	*(*inits$937d2344fd799195)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
	struct _jc_object	*(*methodsOfApplicationClasses$ab8a3ae6562d908b)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods	soot_jimple_toolkits_callgraph_EntryPoints;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs {
	struct _jc_soot_util_NumberedString$object	*sigMain;
	struct _jc_soot_util_NumberedString$object	*sigFinalize;
	struct _jc_soot_util_NumberedString$object	*sigExit;
	struct _jc_soot_util_NumberedString$object	*sigClinit;
	struct _jc_soot_util_NumberedString$object	*sigInit;
	struct _jc_soot_util_NumberedString$object	*sigStart;
	struct _jc_soot_util_NumberedString$object	*sigRun;
	struct _jc_soot_util_NumberedString$object	*sigObjRun;
	struct _jc_soot_util_NumberedString$object	*sigForName;
	struct _jc_soot_RefType$object	*clPrivilegedAction;
	struct _jc_soot_RefType$object	*clPrivilegedExceptionAction;
	struct _jc_soot_RefType$object	*clRunnable;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$refs {
    _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs	soot_jimple_toolkits_callgraph_EntryPoints;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs	soot_jimple_toolkits_callgraph_EntryPoints;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object {
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype _jc_soot_jimple_toolkits_callgraph_EntryPoints$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_EntryPoints, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_EntryPoints$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_EntryPoints_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/EntryPoints.h <==
// public class soot.jimple.toolkits.callgraph.EntryPoints

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b4a094cfa5bff62c soot_jimple_toolkits_callgraph_EntryPoints

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_EntryPoints_H_
#define _JC_soot_jimple_toolkits_callgraph_EntryPoints_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object;
struct _jc_soot_util_NumberedString$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$refs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs	_jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object	_jc_soot_jimple_toolkits_callgraph_EntryPoints$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_EntryPoints$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_EntryPoints$method$addMethod$f4b9793b175f6463(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_EntryPoints$method$addMethod$63a13de99e7c1bf6(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_soot_SootClass$object *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$all$f80bf49325863443(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$application$517d3feed7d4869a(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$clinits$33c8e6b05fa0fe4c(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$implicit$4fb201f0d508bb2b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$inits$937d2344fd799195(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$methodsOfApplicationClasses$ab8a3ae6562d908b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$addMethod$f4b9793b175f6463;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$addMethod$63a13de99e7c1bf6;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$all$f80bf49325863443;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$application$517d3feed7d4869a;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$clinits$33c8e6b05fa0fe4c;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$implicit$4fb201f0d508bb2b;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$inits$937d2344fd799195;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_EntryPoints$method_info$methodsOfApplicationClasses$ab8a3ae6562d908b;

// Static methods
extern struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *_jc_soot_jimple_toolkits_callgraph_EntryPoints$method$v$094cc9979f5b5474(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods {
	void	(*addMethod$f4b9793b175f6463)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*addMethod$63a13de99e7c1bf6)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *, struct _jc_object *, struct _jc_soot_SootClass$object *, struct _jc_soot_util_NumberedString$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*all$f80bf49325863443)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*application$517d3feed7d4869a)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*clinits$33c8e6b05fa0fe4c)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*implicit$4fb201f0d508bb2b)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*inits$937d2344fd799195)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*methodsOfApplicationClasses$ab8a3ae6562d908b)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vmethods	soot_jimple_toolkits_callgraph_EntryPoints;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs {
	struct _jc_soot_util_NumberedString$object	*sigMain;
	struct _jc_soot_util_NumberedString$object	*sigFinalize;
	struct _jc_soot_util_NumberedString$object	*sigExit;
	struct _jc_soot_util_NumberedString$object	*sigClinit;
	struct _jc_soot_util_NumberedString$object	*sigInit;
	struct _jc_soot_util_NumberedString$object	*sigStart;
	struct _jc_soot_util_NumberedString$object	*sigRun;
	struct _jc_soot_util_NumberedString$object	*sigObjRun;
	struct _jc_soot_util_NumberedString$object	*sigForName;
	struct _jc_soot_RefType$object	*clPrivilegedAction;
	struct _jc_soot_RefType$object	*clPrivilegedExceptionAction;
	struct _jc_soot_RefType$object	*clRunnable;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$refs {
    _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_refs	soot_jimple_toolkits_callgraph_EntryPoints;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_EntryPoints$sub_nonrefs	soot_jimple_toolkits_callgraph_EntryPoints;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_EntryPoints$object {
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_EntryPoints$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_EntryPoints$vtype _jc_soot_jimple_toolkits_callgraph_EntryPoints$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_EntryPoints, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_EntryPoints$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_EntryPoints_H_ */
